package com.byteslounge.servlet;

import java.io.IOException;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.byteslounge.ejb.ShoppingCart;
import com.byteslounge.model.Product;

@WebServlet(name = "shoppingServlet", urlPatterns = {"/shopping"})
public class ShoppingServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;
	private static final String SHOPPING_CART_BEAN_SESION_KEY 
		= "shoppingCart";

	protected void doGet(HttpServletRequest request,
		    HttpServletResponse response)
		    throws ServletException, IOException {
		
		// Obtain the EJB from the HTTP session
		ShoppingCart shoppingCartBean = 
			(ShoppingCart) request.getSession()
				.getAttribute(SHOPPING_CART_BEAN_SESION_KEY);
		
		if(shoppingCartBean == null){
			// EJB is not present in the HTTP session
			// so let's fetch a new one from the container
			try {
				InitialContext ic = new InitialContext();
				shoppingCartBean = (ShoppingCart) ic.lookup("java:global/com-byteslounge/com-bytesloungeejb/ShoppingCartBean");
				
				// put EJB in HTTP session for future servlet calls
				request.getSession().setAttribute(SHOPPING_CART_BEAN_SESION_KEY, shoppingCartBean);
				
			} catch (NamingException e) {
				throw new ServletException(e);
			}
		}
		
		String productName = request.getParameter("product");
		if(productName != null && productName.length() > 0){
			// Product is present in the HTTP request.
			// Let's add it to the shopping cart
			Product product = new Product();
			product.setDescription(productName);
			shoppingCartBean.addProduct(product);
		}
		
		String persist = request.getParameter("complete");
		if(persist != null && persist.equalsIgnoreCase("yes")){
			// Request instructs to complete the purchase
			shoppingCartBean.completePurchase();
		}
		
	}
	
}
